/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { ILayoutRestorer, IRouter, JupyterFrontEnd } from "@jupyterlab/application";
import { IWindowResolver, Toolbar } from "@jupyterlab/apputils";
import { IDocumentManager } from "@jupyterlab/docmanager";
import { DocumentRegistry } from "@jupyterlab/docregistry";
import { ContentsManager } from "@jupyterlab/services";
import { IDisposable } from "@lumino/disposable";
import { Widget } from "@lumino/widgets";
import JSZip from "jszip";
import { IFSResource } from "./filesystem";
export declare class FileTree extends Widget {
    cm: ContentsManager;
    dr: DocumentRegistry;
    commands: any;
    toolbar: Toolbar;
    table: HTMLTableElement;
    tree: HTMLElement;
    controller: any;
    selected: string;
    basepath: string;
    constructor({ app, basepath, caption, id, }: FileTree.IOptions);
    buildTable(headers: any, data: any): HTMLTableElement;
    reload(): void;
    restore(): void;
    refresh(): void;
    updateController(oldPath: string, newPath: string): void;
    buildTableContents(data: any, level: number, parent: any): void;
    sortContents(data: any): any[][];
    createTreeElement(object: any, level: number): HTMLTableRowElement;
    download(path: string, folder: boolean): Promise<any>;
    wrapFolder(zip: JSZip, path: string): Promise<void>;
}
export declare namespace FileTree {
    interface IOptions {
        app: JupyterFrontEnd;
        basepath?: string;
        caption?: string;
        id?: string;
    }
    interface ISidebarProps extends IOptions {
        manager: IDocumentManager;
        paths: JupyterFrontEnd.IPaths;
        resolver: IWindowResolver;
        restorer: ILayoutRestorer;
        router: IRouter;
        side?: string;
    }
    function sidebarFromResource(resource: IFSResource, props: FileTree.ISidebarProps): IDisposable;
    function sidebar({ app, manager, paths, resolver, restorer, router, basepath, caption, id, side, }: FileTree.ISidebarProps): IDisposable;
}
